@@ -69,7 +69,7 @@ their Python 3 names and locations::
     from itertools import filterfalse
     # and other moved modules and definitions
 
-It also includes backports for three stdlib packages from Py3 that were
+It also includes backports for these stdlib packages from Py3 that were
 heavily refactored versus Py2::
     
     import html, html.entities, html.parser
@@ -109,7 +109,7 @@ See the docstrings for each of these modules for more info::
 
 Automatic conversion
 --------------------
-An experimental script called ``futurize.py`` is included to aid in
+An experimental script called ``python-futurize`` is included to aid in
 making either Python 2 code or Python 3 code compatible with both
 platforms using the ``future`` module. See
 https://github.com/edschofield/python-future#automatic-conversion.
@@ -172,7 +172,7 @@ else:
 
 __ver_major__ = 0
 __ver_minor__ = 3
-__ver_patch__ = 2
+__ver_patch__ = 3
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
